import { EventStreamCodec } from "@aws-sdk/eventstream-codec";
import { PassThrough, pipeline, Readable } from "stream";
import { EventSigningStream } from "./EventSigningStream";
export class EventStreamPayloadHandler {
    constructor(options) {
        this.eventSigner = options.eventSigner;
        this.eventStreamCodec = new EventStreamCodec(options.utf8Encoder, options.utf8Decoder);
    }
    async handle(next, args, context = {}) {
        const request = args.request;
        const { body: payload, query } = request;
        if (!(payload instanceof Readable)) {
            throw new Error("Eventstream payload must be a Readable stream.");
        }
        const payloadStream = payload;
        request.body = new PassThrough({
            objectMode: true,
        });
        let result;
        try {
            result = await next(args);
        }
        catch (e) {
            request.body.end();
            throw e;
        }
        const match = (request.headers["authorization"] || "").match(/Signature=([\w]+)$/);
        const priorSignature = (match || [])[1] || (query && query["X-Amz-Signature"]) || "";
        const signingStream = new EventSigningStream({
            priorSignature,
            eventStreamCodec: this.eventStreamCodec,
            eventSigner: await this.eventSigner(),
        });
        pipeline(payloadStream, signingStream, request.body, (err) => {
            if (err) {
                throw err;
            }
        });
        return result;
    }
}
